@@ -1,12 +1,7 @@
 use anyhow::Result;
-use aqueue::actor::Actor;
 use aqueue::AQueue;
-use async_trait::async_trait;
-use futures_util::try_join;
-use std::cell::Cell;
 use std::sync::Arc;
 use std::time::Instant;
-use tokio::task::JoinHandle;
 use tokio::time::{sleep, Duration};
 
 static mut VALUE: u64 = 0;
@@ -29,8 +24,7 @@ async fn test_base() -> Result<()> {
             .await;
 
         println!("{:?}", x);
-    })
-    .await?;
+    });
 
     let a_queue = queue.clone();
     tokio::spawn(async move {
@@ -46,8 +40,7 @@ async fn test_base() -> Result<()> {
                 .await
                 .unwrap();
         }
-    })
-    .await?;
+    });
 
     sleep(Duration::from_secs(2)).await;
 
@@ -90,6 +83,11 @@ async fn test_string() -> Result<()> {
     Ok(())
 }
 
+use aqueue::actor::Actor;
+use async_trait::async_trait;
+use std::cell::Cell;
+use tokio::task::JoinHandle;
+
 #[tokio::test]
 async fn test_struct() -> Result<()> {
     #[async_trait]
@@ -148,7 +146,13 @@ async fn test_struct() -> Result<()> {
     let x = make.run(1, 2).await;
     assert_eq!(x, 3);
 
-    let begin = Instant::now();
+    let start = Instant::now();
+    for i in 0..2000000 {
+        make.run(i, i).await;
+    }
+
+    println!("{} {}", start.elapsed().as_secs_f32(), make.inner.get_count());
+
     let a_make = make.clone();
     let a = tokio::spawn(async move {
         let start = Instant::now();
@@ -169,18 +173,8 @@ async fn test_struct() -> Result<()> {
         println!("b {} {}", start.elapsed().as_secs_f32(), b_make.inner.get_count());
     });
 
-    let c = tokio::spawn(async move {
-        let start = Instant::now();
-        for i in 0..2000000 {
-            make.run(i, i).await;
-        }
-        println!("c {} {}", start.elapsed().as_secs_f32(), make.inner.get_count());
-    });
-
-    try_join!(a, b, c)?;
-
-    println!("all secs:{}", begin.elapsed().as_secs_f32());
-
+    a.await?;
+    b.await?;
     Ok(())
 }
 
@@ -298,7 +292,7 @@ async fn test_actor() -> Result<()> {
         }
 
         async fn get_len<'a>(&'a self, b: &'a [u8]) -> Result<usize> {
-            self.inner_call(|_| async move { Ok(b.len()) }).await
+            unsafe { self.inner_call_ref(|_| async move { Ok(b.len()) }).await }
         }
     }
 
